Function coded_chars::control::cursor::line_forward

source ·
pub fn line_forward(n: usize) -> ControlSequence
VPR - Line position forward

VPR causes the active data position to be moved by n line positions in the data component in a direction parallel to the line progression.