Function coded_chars::control::cursor::line_position

source ·
pub fn line_position(n: usize) -> ControlSequence
VPA - Line position absolute

VPA causes the active data position to be moved to line position n in the data component in a direction parallel to the line progression.