Function coded_chars::control::rendition::select_size_unit

source ·
pub fn select_size_unit(size_unit: SizeUnit) -> ControlSequence
SSU - Select size unit

SSU is used to establish the unit in which the numeric parameters of certain control functions are expressed. The established unit remains in effect until the next occurrence of SSU in the data stream.