Function coded_chars::control::tabulation::line_tabulation

source ·
pub fn line_tabulation(n: usize) -> ControlSequence
CVT - Cursor line tabulation

CVT causes the active presentation position to be moved to the corresponding character position of the line corresponding to the n-th following line tabulation stop in the presentation component.