Function next_page

pub fn next_page(n: usize) -> ControlSequence
NP - Next page

NP causes the n-th following page in the presentation component to be displayed, where n equals the value of n. The effect of this control function on the active presentation position is not defined by this Standard.