pub fn erase_char(n: usize) -> ControlSequenceExpand description
ECH - Erase character
If the DEVICE COMPONENT SELECT MODE (DCSM) is set to PRESENTATION, ECH causes the
active presentation position and the n-1 following character positions in the presentation component to
be put into the erased state, where n equals the value of n.
If the DEVICE COMPONENT SELECT MODE (DCSM) is set to DATA, ECH causes the active data
position and the n-1 following character positions in the data component to be put into the erased state,
where n equals the value of n.
Whether the character positions of protected areas are put into the erased state, or the character positions of unprotected areas only, depends on the setting of the ERASURE MODE (ERM).