Function character_orientation

pub fn character_orientation(orientation: Orientation) -> ControlSequence
SCO - Select character orientation

SCO is used to establish the amount of rotation of the graphic characters following in the data stream. The established value remains in effect until the next occurrence of SCO in the data stream.