Function line_home

pub fn line_home(c: usize) -> ControlSequence
SLH - Set line home

If the DEVICE COMPONENT SELECT MODE is set to PRESENTATION, SLH is used to establish at character position n in the active line (the line that contains the active presentation position) and lines of subsequent text in the presentation component the position to which the active presentation position will be moved by subsequent occurrences of CARRIAGE RETURN (CR), DELETE LINE (DL), INSERT LINE (IL) or NEXT LINE (NEL) in the data stream. In the case of a device without data component, it is also the position ahead of which no implicit movement of the active presentation position shall occur.

If the DEVICE COMPONENT SELECT MODE is set to DATA, SLH is used to establish at character position n in the active line (the line that contains the active data position) and lines of subsequent text in the data component the position to which the active data position will be moved by subsequent occurrences of CARRIAGE RETURN (CR), DELETE LINE (DL), INSERT LINE (IL) or NEXT LINE (NEL) in the data stream. It is also the position ahead of which no implicit movement of the active data position shall occur.

The established position is called the line home position and remains in effect until the next occurrence of SLH in the data stream.