Function tabulation_center_on_char

pub fn tabulation_center_on_char(l: usize, ascii: usize) -> ControlSequence
TCC - Tabulation centred on character

TCC causes a character tabulation stop calling for alignment of a target graphic character to be set at character position l in the active line (the line that contains the active presentation position) and lines of subsequent text in the presentation component, and the target character about which centring is to be performed is specified by ascii. TCC causes the replacement of any tabulation stop previously set at that character position, but does not affect other tabulation stops.

The positioning of a text string aligned with a tabulation stop set by TCC will be determined by the first occurrence in the string of the target graphic character; that character will be centred upon the tabulation stop. If the target character does not occur within the string, then the trailing edge of the first character of the string will be positioned at the tabulation stop.

The value of ascii indicates the code table position (binary value) of the target character in the currently invoked code. For a 7-bit code, the permissible range of values is 32 to 127; for an 8-bit code, the permissible range of values is 32 to 127 and 160 to 255.