Function coded_chars::control::view::select_directions
source · pub fn select_directions(
line_orientation: LineOrientation,
line_progression: CharacterPath,
character_path: CharacterPath,
path_effect: PathEffect,
) -> ControlSequenceExpand description
SPD - Select presentation directions
SPD is used to select the line orientation, the line progression, and the character path in the presentation component. It is also used to update the content of the presentation component and the content of the data component. This takes effect immediately.