Function coded_chars::control::view::select_extent
source · pub fn select_extent(editing_extent: EditingExtent) -> ControlSequenceExpand description
SEE - Select editing extent
SEE is used to establish the editing extent for subsequent character or line insertion or deletion. The established extent remains in effect until the next occurrence of SEE in the data stream.