pub fn line_spacing(n: usize) -> ControlSequenceExpand description
SLS - Set line spacing
SLS is used to establish the line spacing for subsequent text. The established spacing remains in effect until the next occurrence of SLS or of SELECT LINE SPACING (SVS) or of SPACING INCREMENT (SPI) in the data stream.
The unit in which the parameter value is expressed is that established by the parameter value of SELECT SIZE UNIT (SSU).